@@ -30,7 +30,7 @@ pub struct FormatterInfo {
     pub work_dir: PathBuf,
 }
 
-#[derive(Debug, Deserialize, Serialize)]
+#[derive(Debug, Default, Deserialize, Serialize)]
 /// RootManifest
 pub struct CacheManifest {
     /// Map of all the formatter infos
@@ -39,15 +39,6 @@ pub struct CacheManifest {
     pub matches: BTreeMap<FormatterName, BTreeMap<PathBuf, Mtime>>,
 }
 
-impl Default for CacheManifest {
-    fn default() -> Self {
-        Self {
-            formatters: BTreeMap::new(),
-            matches: BTreeMap::new(),
-        }
-    }
-}
-
 impl Clone for CacheManifest {
     fn clone(&self) -> Self {
         Self {
@@ -127,7 +118,7 @@ impl CacheManifest {
 
         // Now discard all the paths who don't have an associated formatter
         for name in old_formatters.keys() {
-            self.matches.remove(&name);
+            self.matches.remove(name);
         }
     }
 
